/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/tinderbox/XR-Trunk/Linux_2.6.18-8.el5_Depend/mozilla/dom/public/idl/base/nsIDOMClientInformation.idl
 */

#ifndef __gen_nsIDOMClientInformation_h__
#define __gen_nsIDOMClientInformation_h__


#ifndef __gen_domstubs_h__
#include "domstubs.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIDOMOfflineResourceList; /* forward declaration */

class nsIDOMLoadStatusList; /* forward declaration */


/* starting interface:    nsIDOMClientInformation */
#define NS_IDOMCLIENTINFORMATION_IID_STR "02bb1271-05dd-4bde-a9ca-68571bf8c702"

#define NS_IDOMCLIENTINFORMATION_IID \
  {0x02bb1271, 0x05dd, 0x4bde, \
    { 0xa9, 0xca, 0x68, 0x57, 0x1b, 0xf8, 0xc7, 0x02 }}

class NS_NO_VTABLE nsIDOMClientInformation : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMCLIENTINFORMATION_IID)

  /**
   * Web Applications 1.0 Browser State: registerContentHandler
   * Allows web services to register themselves as handlers for certain content
   * types.
   * http://whatwg.org/specs/web-apps/current-work/
   */
  /* void registerContentHandler (in DOMString mimeType, in DOMString uri, in DOMString title); */
  NS_IMETHOD RegisterContentHandler(const nsAString & mimeType, const nsAString & uri, const nsAString & title) = 0;

  /* void registerProtocolHandler (in DOMString protocol, in DOMString uri, in DOMString title); */
  NS_IMETHOD RegisterProtocolHandler(const nsAString & protocol, const nsAString & uri, const nsAString & title) = 0;

  /* boolean isLocallyAvailable (in DOMString uri, in boolean whenOffline); */
  NS_IMETHOD IsLocallyAvailable(const nsAString & uri, PRBool whenOffline, PRBool *_retval) = 0;

  /* readonly attribute nsIDOMOfflineResourceList offlineResources; */
  NS_IMETHOD GetOfflineResources(nsIDOMOfflineResourceList * *aOfflineResources) = 0;

  /* readonly attribute nsIDOMLoadStatusList pendingOfflineLoads; */
  NS_IMETHOD GetPendingOfflineLoads(nsIDOMLoadStatusList * *aPendingOfflineLoads) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMClientInformation, NS_IDOMCLIENTINFORMATION_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMCLIENTINFORMATION \
  NS_IMETHOD RegisterContentHandler(const nsAString & mimeType, const nsAString & uri, const nsAString & title); \
  NS_IMETHOD RegisterProtocolHandler(const nsAString & protocol, const nsAString & uri, const nsAString & title); \
  NS_IMETHOD IsLocallyAvailable(const nsAString & uri, PRBool whenOffline, PRBool *_retval); \
  NS_IMETHOD GetOfflineResources(nsIDOMOfflineResourceList * *aOfflineResources); \
  NS_IMETHOD GetPendingOfflineLoads(nsIDOMLoadStatusList * *aPendingOfflineLoads); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMCLIENTINFORMATION(_to) \
  NS_IMETHOD RegisterContentHandler(const nsAString & mimeType, const nsAString & uri, const nsAString & title) { return _to RegisterContentHandler(mimeType, uri, title); } \
  NS_IMETHOD RegisterProtocolHandler(const nsAString & protocol, const nsAString & uri, const nsAString & title) { return _to RegisterProtocolHandler(protocol, uri, title); } \
  NS_IMETHOD IsLocallyAvailable(const nsAString & uri, PRBool whenOffline, PRBool *_retval) { return _to IsLocallyAvailable(uri, whenOffline, _retval); } \
  NS_IMETHOD GetOfflineResources(nsIDOMOfflineResourceList * *aOfflineResources) { return _to GetOfflineResources(aOfflineResources); } \
  NS_IMETHOD GetPendingOfflineLoads(nsIDOMLoadStatusList * *aPendingOfflineLoads) { return _to GetPendingOfflineLoads(aPendingOfflineLoads); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMCLIENTINFORMATION(_to) \
  NS_IMETHOD RegisterContentHandler(const nsAString & mimeType, const nsAString & uri, const nsAString & title) { return !_to ? NS_ERROR_NULL_POINTER : _to->RegisterContentHandler(mimeType, uri, title); } \
  NS_IMETHOD RegisterProtocolHandler(const nsAString & protocol, const nsAString & uri, const nsAString & title) { return !_to ? NS_ERROR_NULL_POINTER : _to->RegisterProtocolHandler(protocol, uri, title); } \
  NS_IMETHOD IsLocallyAvailable(const nsAString & uri, PRBool whenOffline, PRBool *_retval) { return !_to ? NS_ERROR_NULL_POINTER : _to->IsLocallyAvailable(uri, whenOffline, _retval); } \
  NS_IMETHOD GetOfflineResources(nsIDOMOfflineResourceList * *aOfflineResources) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetOfflineResources(aOfflineResources); } \
  NS_IMETHOD GetPendingOfflineLoads(nsIDOMLoadStatusList * *aPendingOfflineLoads) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetPendingOfflineLoads(aPendingOfflineLoads); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMClientInformation : public nsIDOMClientInformation
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMCLIENTINFORMATION

  nsDOMClientInformation();

private:
  ~nsDOMClientInformation();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMClientInformation, nsIDOMClientInformation)

nsDOMClientInformation::nsDOMClientInformation()
{
  /* member initializers and constructor code */
}

nsDOMClientInformation::~nsDOMClientInformation()
{
  /* destructor code */
}

/* void registerContentHandler (in DOMString mimeType, in DOMString uri, in DOMString title); */
NS_IMETHODIMP nsDOMClientInformation::RegisterContentHandler(const nsAString & mimeType, const nsAString & uri, const nsAString & title)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void registerProtocolHandler (in DOMString protocol, in DOMString uri, in DOMString title); */
NS_IMETHODIMP nsDOMClientInformation::RegisterProtocolHandler(const nsAString & protocol, const nsAString & uri, const nsAString & title)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* boolean isLocallyAvailable (in DOMString uri, in boolean whenOffline); */
NS_IMETHODIMP nsDOMClientInformation::IsLocallyAvailable(const nsAString & uri, PRBool whenOffline, PRBool *_retval)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIDOMOfflineResourceList offlineResources; */
NS_IMETHODIMP nsDOMClientInformation::GetOfflineResources(nsIDOMOfflineResourceList * *aOfflineResources)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* readonly attribute nsIDOMLoadStatusList pendingOfflineLoads; */
NS_IMETHODIMP nsDOMClientInformation::GetPendingOfflineLoads(nsIDOMLoadStatusList * *aPendingOfflineLoads)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMClientInformation_h__ */
